package com.alibaba.ailabs.genie.assistant.demo;

import android.content.Context;
import android.content.Intent;
import android.graphics.Typeface;
import android.os.Build;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.RequiresApi;

import com.alibaba.ailabs.genie.assistant.demo.asr.ASRClientActivity;
import com.alibaba.ailabs.genie.assistant.demo.play.PlayStatusActivity;
import com.alibaba.ailabs.genie.assistant.demo.play.TtsActivity;
import com.alibaba.ailabs.genie.assistant.demo.userInfo.UserInfoActivity;
import com.alibaba.ailabs.genie.assistant.demo.utils.ListBean;
import com.alibaba.ailabs.genie.assistant.demo.view.AnimatedExpandableListView;

import org.json.JSONArray;
import org.json.JSONObject;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;

public class MainActivity extends BaseActivity {
    private AnimatedExpandableListView listView;
    private ArrayList<ListBean> mListBean;

    @RequiresApi(api = Build.VERSION_CODES.LOLLIPOP)
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        setTitle("AgentDemo");
        parseEasyJson();
        ExampleAdapter adapter = new ExampleAdapter(this);
        adapter.setData(mListBean);
        listView = findViewById(R.id.listView);
        listView.setAdapter(adapter);
        listView.setOnGroupClickListener((parent, v, groupPosition, id) -> {
            if (listView.isGroupExpanded(groupPosition)) {
                listView.collapseGroupWithAnimation(groupPosition);
            } else {
                listView.expandGroupWithAnimation(groupPosition);
            }
            return true;
        });
        listView.setOnChildClickListener((parent, v, groupPosition, childPosition, id) -> {
            Class<?> mActivityName = null;
            String ItemName = mListBean.get(groupPosition).getSecondList().get(childPosition);

            switch (ItemName) {
                case "用户信息": mActivityName = UserInfoActivity.class; break;
                case "动态意图":
                case "自定义意图":
                case "公共意图": mActivityName = ASRClientActivity.class; break;
                case "TTS控制": mActivityName = TtsActivity.class; break;
                case "手势控制": mActivityName = MmiActivity.class; break;
                case "播放状态": mActivityName = PlayStatusActivity.class; break;
                default: Toast.makeText(v.getContext(), ItemName + "暂未开放", Toast.LENGTH_SHORT).show(); break;
            }
            if (mActivityName != null) {
                Intent intent = new Intent(MainActivity.this, mActivityName);
                intent.putExtra("ItemName", ItemName);
                startActivity(intent);
            }
            return true;
        });
    }

    private static class ChildHolder {
        TextView title;
    }

    private static class GroupHolder {
        TextView title, titleIcon, arrow;
    }

    private void parseEasyJson(){
        mListBean = new ArrayList<>();
        try{
            InputStreamReader inputStreamReader = new InputStreamReader(getAssets().open("test.json"), "UTF-8");
            BufferedReader bufferedReader = new BufferedReader(inputStreamReader);

            String line;
            StringBuilder stringBuilder = new StringBuilder();
            while((line = bufferedReader.readLine()) != null) {
                stringBuilder.append(line);
            }
            bufferedReader.close();
            inputStreamReader.close();

            JSONObject jsonObject = new JSONObject(stringBuilder.toString());
            JSONArray jsonArray = jsonObject.getJSONArray("responseList");
            for(int i = 0;i < jsonArray.length();i++){
                ListBean mResponse = new ListBean();
                List<String> name = new ArrayList<>();
                JSONObject mJsonObject = (JSONObject) jsonArray.get(i);
                mResponse.setName(mJsonObject.getString("name"));
                JSONArray secondList = mJsonObject.getJSONArray("secondList");
                for(int v = 0;v < secondList.length();v++){
                    String secondName = (String) secondList.get(v);
                    name.add(secondName);
                }
                mResponse.setSecondList(name);
                mListBean.add(mResponse);
            }
        } catch (Exception e){
            e.printStackTrace();
        }
    }

    private class ExampleAdapter extends AnimatedExpandableListView.AnimatedExpandableListAdapter {
        private final LayoutInflater inflater;

        private List<ListBean> items;

        public ExampleAdapter(Context context) {
            inflater = LayoutInflater.from(context);
        }

        public void setData(List<ListBean> items) {
            this.items = items;
        }

        @Override
        public String getChild(int groupPosition, int childPosition) {
            return items.get(groupPosition).getSecondList().get(childPosition);
        }

        @Override
        public long getChildId(int groupPosition, int childPosition) {
            return childPosition;
        }

        @Override
        public View getRealChildView(int groupPosition, int childPosition, boolean isLastChild, View convertView, ViewGroup parent) {
            ChildHolder holder;
            String item = getChild(groupPosition, childPosition);
            if (convertView == null) {
                holder = new ChildHolder();
                convertView = inflater.inflate(R.layout.list_item, parent, false);
                holder.title = (TextView) convertView.findViewById(R.id.textTitle);
                convertView.setTag(holder);
            } else {
                holder = (ChildHolder) convertView.getTag();
            }
            holder.title.setText(item);
            return convertView;
        }

        @Override
        public int getRealChildrenCount(int groupPosition) {
            return items.get(groupPosition).getSecondList().size();
        }

        @Override
        public ListBean getGroup(int groupPosition) {
            return items.get(groupPosition);
        }

        @Override
        public int getGroupCount() {
            return items.size();
        }

        @Override
        public long getGroupId(int groupPosition) {
            return groupPosition;
        }

        @Override
        public View getGroupView(int groupPosition, boolean isExpanded, View convertView, ViewGroup parent) {
            GroupHolder holder;
            ListBean item = getGroup(groupPosition);
            if (convertView == null) {
                holder = new GroupHolder();
                convertView = inflater.inflate(R.layout.group_item, parent, false);
                holder.title = (TextView) convertView.findViewById(R.id.textTitle);
                holder.arrow = convertView.findViewById(R.id.arrow);
                convertView.setTag(holder);
            } else {
                holder = (GroupHolder) convertView.getTag();
            }

            Typeface iconfont = Typeface.createFromAsset(getAssets(), "iconfont/iconfont.ttf");
            holder.title.setText(item.getName());
            holder.arrow.setTypeface(iconfont);
            if (isExpanded) {
                holder.arrow.animate().setDuration(250).rotation(-180).start();
            } else {
                holder.arrow.animate().setDuration(150).rotation(0).start();
            }
            return convertView;
        }

        @Override
        public boolean hasStableIds() {
            return true;
        }

        @Override
        public boolean isChildSelectable(int arg0, int arg1) {
            return true;
        }

    }
}
