package com.alibaba.ailabs.genie.assistant.demo.asr;

import android.graphics.Color;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.SpannableString;
import android.text.Spanned;
import android.text.style.ForegroundColorSpan;
import android.util.Log;
import android.view.View;
import android.widget.ScrollView;
import android.widget.TextView;

import com.alibaba.ailabs.genie.assistant.demo.BaseActivity;
import com.alibaba.ailabs.genie.assistant.demo.R;
import com.alibaba.ailabs.genie.assistant.sdk.asr.ASRClient;
import com.alibaba.ailabs.genie.assistant.sdk.asr.ASRCommandReturn;
import com.alibaba.ailabs.genie.assistant.sdk.asr.AppContextData;
import com.alibaba.ailabs.genie.assistant.sdk.asr.DMAction;
import com.alibaba.ailabs.genie.assistant.sdk.asr.GenieApi;
import com.alibaba.ailabs.genie.assistant.sdk.asr.OnASRCommandListener;
import com.alibaba.ailabs.genie.assistant.sdk.asr.OnGetMediaPolicyListener;
import com.alibaba.ailabs.genie.assistant.sdk.asr.SelectListData;

/**
 * 示例: 演示语音识别、自定义意图、动态意图、公共意图如何处理
 */
public class ASRClientActivity extends BaseActivity implements
        GenieApi.onTtsListener,
        OnGetMediaPolicyListener{
    private static final String TAG = "ASRClientActivity";

    private static final int MESSAGE_ASR_SDK = 2000;

    private String ItemName;
    private ScrollView mASRResultScrollView;
    private TextView mASRResultView, mASRTextView, mASRTips;
    private ASRClient mAliTVASRManager;

    private OnASRCommandListener mASRCommandListener = new OnASRCommandListener() {

        @Override
        public void onASRServiceStatusUpdated(ASRServiceStatus arg0) {
            Message msg = mHandler.obtainMessage();
            msg.what = MESSAGE_ASR_SDK;
            if (arg0 == ASRServiceStatus.ASR_SERVICE_STATUS_CONNECTED)
                msg.obj = "语音服务注册成功...（" + Thread.currentThread().getId() + "）";
            else
                msg.obj = "语音服务注册失败...（" + Thread.currentThread().getId() + "）";

            mHandler.sendMessage(msg);
        }

        @Override
        public void onASRStatusUpdated(ASRStatus arg0, Bundle arg1) {
            Log.d(TAG, "ASRStatus: " + arg0 + ", Bundle: " + arg1);
        }

        /**
         * 重要！！！接收到有限的语音指令结果并进行处理。
         * @param commandDomain 指令所属域
         * @param command 指令名
         * @param commandParams 指令参数
         * @param nluResult nlu结果详细数据
         * @return 指令处理结果（注意：公共意图一定需要返回处理结果，含已处理或未处理）
         */
        @Override
        public ASRCommandReturn onNLUResult(String commandDomain, String command,
                                            String commandParams, Bundle nluResult) {
            ASRCommandReturn result = processNLPResult(commandDomain, command, commandParams, nluResult);
            Log.e("WordGuo", "command: " + command);
            //TODO 自定义意图、动态意图
            if(command.equals("/NluResult")){
                // NluResult结果...
            }

            //TODO 公共意图
            if (DMAction.MULTIMEDIA_FASTFORWARD.equalsIgnoreCase(command)){
                // 例如：app根据需求处理快进指令
                // TODO：具体操作

                // 重要！！！注意：最后需返回已处理结果
                result.mIsHandled = true;
                // 其他result字段根据需求自行填充
            }else{
                // 未处理
                result.mIsHandled = false;
            }

            Message msg = mHandler.obtainMessage();
            msg.what = MESSAGE_ASR_SDK;
            msg.obj = "onNLUResult (" + Thread.currentThread().getId() + "): host:" +
                    commandDomain + ", path:" + command + ", param:" + commandParams + ", handled:" + result.mIsHandled
                    + "voiceId = " + ((null != nluResult) ? nluResult.getString("voiceId") : "");

            mHandler.sendMessage(msg);

            return result;
        }

        /**
         * 重要！！！用于做所见即可说的上下文填充。
         * 一般填充界面上的文本内容，主要用于ASR增强及当前技能的优先匹配。
         * @param appContextData
         */
        @Override
        public void getAppContextData(AppContextData appContextData) {
            //天猫精灵给我放一首刘德华的冰雨吧
            //动态语料： 天猫精灵给我放一首${artist}的${song}吧
            // 设置该应用的技能安全秘钥。（请提前到天猫精灵技能应用开放平台申请到认证信息）
            appContextData.setSecretKey("f87a48e1-382c-4585-9950-04cb46794d1d");
            // 如果语料未命中技能，可以执行精灵默认流程。默认为true。
            appContextData.setCanExitSkill(true);

            //TODO 配置 动态意图 参照: https://aligenie.com/doc/20255408/omuzxq
            SelectListData selectListData = new SelectListData();
            // 设置当前页面的pageid。（请提前在天猫精灵技能应用开放平台配置该页面id）
            selectListData.setPageId("1300003");

            //slots - name。slotName对应技能平台 语音交互模型 -> 意图 -> 意图编辑 -> 参数名称
            SelectListData.SelectListItem artistEntity = new SelectListData.SelectListItem();
            artistEntity.setSelectKey("刘德华");  //用于标记
            artistEntity.addSelectValue("刘德华");
            artistEntity.addSelectValue("华仔");
            selectListData.addSelectData("name", artistEntity);

            //slots - songName。slotName对应技能平台 语音交互模型 -> 意图 -> 意图编辑 -> 参数名称
            SelectListData.SelectListItem songEntity = new SelectListData.SelectListItem();
            artistEntity.setSelectKey("忘情水");  //用于标记
            artistEntity.addSelectValue("忘情水");
            artistEntity.addSelectValue("忘情灰");
            selectListData.addSelectData("songName", songEntity);

            appContextData.setSelectListData(selectListData);

            Log.d(TAG, "getAppContextData: " + appContextData.toString());
        }

        @Override
        public Bundle getSceneInfo(Bundle sceneBundle) {
            return null;
        }

        @Override
        public Bundle asrToClient(Bundle bundle) {
            //语音识别结果
            final String asrText = (String) bundle.get("asr");
            runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    mASRTextView.setText("语音识别结果: \n" + asrText + " ·");
                    String content = mASRTextView.getText().toString();
                    SpannableString ss = new SpannableString(content);
                    ss.setSpan(new ForegroundColorSpan(Color.parseColor("#ff0000")), content.indexOf(asrText), content.indexOf(" ·"), Spanned.SPAN_EXCLUSIVE_EXCLUSIVE);
                    mASRTextView.setText(ss);
                }
            });
            return null;
        }
    };

    private ASRCommandReturn processNLPResult(String host, String path, String param, Bundle nlp) {
        ASRCommandReturn result = new ASRCommandReturn();
        if (DMAction.MULTIMEDIA_PLAY.equals(path)) {
            //播放
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_DOWNLOAD.equals(path)) {
            //下载
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_COLLECT.equals(path)) {
            //收藏
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_SELECT.equals(path)) {
            //选集
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_FASTFORWARD.equals(path)) {
            //快进
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_FASTBACKWARD.equals(path)) {
            //快退
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_FULLSCREEN_ENTER.equals(path)) {
            //全屏
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_FULLSCREEN_EXIT.equals(path)) {
            //退出全屏
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_PURCHASE.equals(path)) {
            //购买
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_FOLLOW.equals(path)) {
            //追剧
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_BULLETSCREEN.equals(path)) {
            //打开弹幕输入
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_BULLETSCREEN_CLOSE.equals(path)) {
            //关闭弹幕
            result.mIsHandled = true;
            result.mOpenFarMic = true;
            result.mForceClose = true;
            result.mSpokenMessage = "正在为你关闭弹幕功能";

        } else if (DMAction.MULTIMEDIA_BULLETSCREEN_OPEN.equals(path)) {
            //打开弹幕
            result.mIsHandled = true;
            result.mOpenFarMic = false;
            result.mForceClose = true;
            result.mSpokenMessage = "正在为你开启弹幕功能";

        } else if (DMAction.MULTIMEDIA_SETUP.equals(path)) {
            //设置
            result.mIsHandled = true;
        } else if (DMAction.MULTIMEDIA_SETUP_OPEN.equals(path)) {
            //设置开启
            result.mIsHandled = true;
        }

        return result;
    }

    private Handler mHandler = new Handler(Looper.getMainLooper()) {
        @Override
        public void handleMessage(Message msg) {
            Log.d(TAG, msg.toString());
            switch (msg.what) {
                case MESSAGE_ASR_SDK: {
                    if (mASRResultView != null) {
                        mASRResultView.append((String) msg.obj + "\n\n");
                    }
                }
                break;
            }
        }

    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        mAliTVASRManager = new ASRClient(this);
        setContentView(R.layout.asr_client_activity);
        ItemName = getIntent().getStringExtra("ItemName");
        setTitle(ItemName);
        setBackBtn();
        mASRResultScrollView = (ScrollView) findViewById(R.id.asr_result_scroll_view);
        mASRResultView = (TextView) findViewById(R.id.asr_result_view);
        mASRTextView = (TextView)findViewById(R.id.asr_text);
        mASRTips = (TextView)findViewById(R.id.asr_tips);
        mASRResultView.setVisibility(View.VISIBLE);
        if (ItemName.equals("动态意图")) {
            mASRTips.append("播放刘德华的歌\n");
            mASRTips.append("需要在语音交互模型里配置对应的动态意图");
        } else if (ItemName.equals("自定义意图")) {
            mASRTips.append("打开窗户\n");
            mASRTips.append("需要在语音交互模型里配置对应的自定义意图");
        } else if (ItemName.equals("公共意图")) {
            mASRTips.append("快进\n");
            mASRTips.append("需要在语音交互模型里配置对应的公共意图");
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        // 注册（注意一定要和注销成对出现）
        try {
            // 设置常驻服务是否接收语音
            mAliTVASRManager.setBackgroundService(true);
            // 设置语音指令回调监听器
            mAliTVASRManager.setOnASRCommandListener(mASRCommandListener);
            // Option：设置应用包名，不设置会自动填充当前app所属包名
            mAliTVASRManager.setPackageName("com.alibaba.ailabs.genie.assistant.demo");
            // 设置监听器类型
            mAliTVASRManager.setASRListenerType(OnASRCommandListener.ASRListenerType.DEFAULT_LISTENER);
            // 设置使能
            mAliTVASRManager.setAliTVASREnable(true);
            // 语音控制器初始化
            mAliTVASRManager.init(this, true);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    protected void onPause() {
        super.onPause();
        // 注销（注意一定要和注册成对出现）
        mAliTVASRManager.release();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        mAliTVASRManager.release();
    }

    @Override
    public void onTtsCallback(int id, int status) {

    }

    @Override
    public int onGetMediaPolicy() {
        return OnGetMediaPolicyListener.POLICY_CALL_PHONE;
    }

}
