package com.alibaba.ailabs.genie.assistant.demo.play;

import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.alibaba.ailabs.genie.assistant.demo.BaseActivity;
import com.alibaba.ailabs.genie.assistant.demo.R;
import com.alibaba.ailabs.genie.assistant.sdk.asr.MediaStatusReport;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;


/**
 * 播放状态:
 * https://aligenie.com/doc/20255408/peycst 《APP播放状态上报规范》
 */
public class PlayStatusActivity extends BaseActivity implements View.OnClickListener {
    private TextView playStatusLog, playStatusLog2;
    private static final int MESSAGE_PLAY_STATUS = 1300;

    private boolean isTouchCommit = false;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_play_status);
        playStatusLog = findViewById(R.id.play_status_log1);
        playStatusLog2 = findViewById(R.id.play_status_log2);
        Button play = findViewById(R.id.play_status_button);
        Button stop = findViewById(R.id.stop_status_button);
        play.setOnClickListener(this);
        stop.setOnClickListener(this);
        setTitle("播放状态");
        setBackBtn();
        this.printLog();
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.play_status_button:
                this.commitStatus(MediaStatusReport.MEDIA_PLAYBACK_STARTED);
                break;
            case R.id.stop_status_button:
                this.commitStatus(MediaStatusReport.MEDIA_PLAYBACK_STOPPED);
                break;
        }
    }

    public void commitStatus(int playStatus) {
        playStatusLog.setText("");
        playStatusLog2.setText("");
        isTouchCommit = true;
        // 组装播放数据状态实例
        MediaStatusReport.MediaStatusInfo info = new MediaStatusReport.MediaStatusInfo();
        // 如有需补齐
        info.audioId = "111";
        info.albumId = "222";
        info.categoryId = "333";
        info.tagId = "444";
        info.searchId = "555";
        info.audioSource = "xiami";
        info.audioName = "777";
        info.audioAnchor = "888";
        info.audioAlbum = "999";
        info.progress = "360";
        info.playerType = "";
        info.audioExt = "";
        info.audioLength = "2400";
        info.extendInfo = "";

        // 上报播放状态。此处已开始播放为例。
        MediaStatusReport.setStatus(this,MediaStatusReport.MEDIA_TYPE_VIDEO,playStatus,info);
    }

    public void printLog() {
        new Thread(new Runnable() {
            @Override
            public void run() {
                Process mLogcatProc = null;
                BufferedReader reader = null;

                try {
                    String[] running = new String[]{"logcat","-s","MediaTable:D *:S", "com.alibaba.ailabs.genie.second.gcs.service.GenieUTService:I *:S"};
                    mLogcatProc = Runtime.getRuntime().exec(running);
                    reader = new BufferedReader(new InputStreamReader(mLogcatProc.getInputStream()));
                    String line;

                    while ((line = reader.readLine()) != null) {

                        if (isTouchCommit) {
                            Message msg = mHandler.obtainMessage();
                            msg.what = MESSAGE_PLAY_STATUS;
                            msg.obj = line;

                            mHandler.sendMessage(msg);
                        }
                    }
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }).start();
    }

    private Handler mHandler = new Handler(Looper.getMainLooper()) {
        @Override
        public void handleMessage(Message msg) {
            switch (msg.what) {
                case MESSAGE_PLAY_STATUS: {
                    String message = (String) msg.obj;
                    if (message.contains("MediaTable: media")) {
                        playStatusLog.setText(message);
                    } else if (message.contains("GenieUTService: customHit, eventName=ThirdApp_player")){
                        playStatusLog2.setText(message);
                    }
                }
                break;
            }
        }

    };

    @Override
    protected void onDestroy() {
        super.onDestroy();
        isTouchCommit = false;
    }
}
