package com.alibaba.ailabs.genie.assistant.demo.play;

import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;

import com.alibaba.ailabs.genie.assistant.demo.BaseActivity;
import com.alibaba.ailabs.genie.assistant.demo.R;
import com.alibaba.ailabs.genie.assistant.sdk.asr.GenieApi;

/**
 * TTS控制:
 * https://aligenie.com/doc/20255408/kgvhpi
 */
public class TtsActivity extends BaseActivity implements View.OnClickListener {
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_tts);
        setTitle("TTS控制");
        setBackBtn();
        Button ttsPlay = findViewById(R.id.tts_play);
        Button ttsClose = findViewById(R.id.tts_close);
        Button ttsMute = findViewById(R.id.tts_mute);
        Button ttsReply = findViewById(R.id.tts_reply);
        Button ttsOpenMic = findViewById(R.id.tts_open_mic);
        Button ttsStop = findViewById(R.id.tts_stop);
        ttsPlay.setOnClickListener(this);
        ttsClose.setOnClickListener(this);
        ttsMute.setOnClickListener(this);
        ttsReply.setOnClickListener(this);
        ttsOpenMic.setOnClickListener(this);
        ttsStop.setOnClickListener(this);
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.tts_play:
                this.ttsControllerMic("播放完TTS后开麦收音",true);
                break;
            case R.id.tts_close:
                this.ttsControllerMic("播放完TTS后关麦停止收音", false);
                break;
            case R.id.tts_mute:
                this.ttsController("静音时仍可以TTS播放", false, true, false);
                break;
            case R.id.tts_reply:
                this.ttsController("TTS播放状态反馈给云端", false, false, true);
                break;
            case R.id.tts_open_mic:
                this.ttsControllerMic("",true);
                break;
            case R.id.tts_stop:
                GenieApi.stopTTS(this, -1);
                break;
        }
    }

    public void ttsControllerMic(String tts, boolean isOpenMic) {
        /**
         * TTS播放和开麦操作，第三方应用需要传递认证信息
         *
         * @param context 上下文
         * @param sessionId 会话ID
         * @param tts TTS文本
         * @param isOpenMic 播放完TTS后是否开麦。默认false。
         * @param wakeupType 唤醒类型。默认为1。
         * @param secretKey 应用认证秘钥信息。从天猫精灵智能应用平台上申请。
         * @param listener TTS状态监听器
         * @return TTS播放标识ID
         */
        GenieApi.playTTS(TtsActivity.this, 0, tts, isOpenMic, GenieApi.WAKEUP_VOICEPRINT, "f87a48e1-382c-4585-9950-04cb46794d1d", new GenieApi.onTtsListener() {
            @Override
            public void onTtsCallback(int id, int status) {
                Log.e(TAG, "id = " + id + ", status = " + status);
            }
        });
    }

    public void ttsController(String tts, boolean isOpenMic, boolean ignoreMute, boolean isFeedback) {
        /**
         * tts播放和开麦操作，第三方应用需要传递认证信息
         *
         * @param context 上下文
         * @param sessionId 会话ID
         * @param tts TTS文本
         * @param isOpenMic 播放完TTS后是否开麦。默认false。
         * @param ignoreMute 是否忽略静音。默认false。
         * @param isFeedback 是否回复。默认false。
         * @param wakeupType 唤醒类型。默认为1。
         * @param secretKey 应用认证秘钥信息。从天猫精灵智能应用平台上申请。
         * @param listener TTS状态监听器
         * @return TTS播放标识ID
         */
        GenieApi.playTTS(
                TtsActivity.this,
                0,
                tts,
                isOpenMic,
                ignoreMute,
                isFeedback,
                GenieApi.WAKEUP_VOICEPRINT,
                "f87a48e1-382c-4585-9950-04cb46794d1d",
                new GenieApi.onTtsListener() {
            @Override
            public void onTtsCallback(int id, int status) {
                Log.e(TAG, "id = " + id + ", status = " + status);
            }
        });
    }
}
