# Android 工程集成 AGIS 步骤

## 集成步骤

### 一、添加依赖

- 添加 maven 地址:
  [你的 android 工程]/build.gradle

  ```groovy
  // Top-level build file where you can add configuration options common to all sub-projects/modules.

  buildscript {
      // 省略
  }

  allprojects {
      repositories {
          // 省略

          // AGUIAgentSDK依赖
          maven { url "http://mvnrepo.alibaba-inc.com/mvn/repository" }
      }
  }
  ```

- 添加 AGUIAgentSDK 依赖
  app/build.gradle

  ```groovy
  apply plugin: 'com.android.application'

  android {
      // 省略
  }

  dependencies {
      //省略

      // AGUIAgentSDK依赖
      implementation(name: 'ailabsSDK-3.0.0.151', ext: 'aar')
  }

  ```

---

### 二、设置AGUI（详见demo代码）

```Java
    // ASR回调
    private OnASRCommandListener mOnASRCommandListener = new OnASRCommandListener() {
        @Override
        public void onASRStatusUpdated(ASRStatus asrStatus, Bundle bundle) {

        }

        @Override
        public void onASRServiceStatusUpdated(ASRServiceStatus asrServiceStatus) {

        }

        @Override
        public ASRCommandReturn onASRResult(String s, boolean b) {
            return null;
        }

        @Override
        public ASRCommandReturn onNLUResult(String s, String s1, String s2, Bundle bundle) {
            return null;
        }

        @Override
        public void getAppContextData(AppContextData appContextData) {
            Log.d(TAG, "before getAppContextData.");
            appContextData.setSecretKey("YourSecretKey");
            appContextData.setCanExitSkill(true);
            SelectListData selectListData = new SelectListData();
            appContextData.setSelectListData(selectListData);
            Log.d(TAG, "after getAppContextData.");
        }

        @Override
        public Bundle getSceneInfo(Bundle bundle) {
            return null;
        }

        @Override
        public Bundle asrToClient(Bundle bundle) {
            return null;
        }
    };
```

```Java
   @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        Log.d(TAG, "before init ASRClient");
        mAsrClient = new ASRClient(getApplicationContext());
        mAsrClient.setBackgroundService(false);//设置常驻服务是否接收语音
        mAsrClient.setOnASRCommandListener(mOnASRCommandListener); //注册语音回调
        mAsrClient.setASRListenerType(OnASRCommandListener.ASRListenerType.DEFAULT_LISTENER);
        mAsrClient.init(getApplicationContext(), true); //初始化 AliTVManager
        Log.d(TAG, "after init ASRClient()");
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        mAsrClient.release();
    }

```

**ps: 添加上述代码就可以了，但是我们上面代码中需要填写一个重要参数:             appContextData.setSecretKey("YourSecretKey");**

## 三、获取SecretKey步骤

### [创建技能](https://admin-skill.alibaba-inc.com/console/skill/list)

![技能信息](./img/技能信息.jpg)

### 生成SecretKey

技能 -> App 界面配置 -> 配置 App 信息 -> 关联 apk 中填以下信息
![配置App信息](./img/配置App信息.jpg)
获取 Fingerprint 方法:

1. 提取apk信息`keytool -list -printcert -jarfile your_apk_name.apk`
2. 取出SHA1后的信息: `0D:50:04:65:77:CF:F3:B5:DE:8D:7A:F7:C1:F0:C9:BC:2B:A6:BE:25`
3. 去掉其中的`:`号，转换成小写: `0d50046577cff3b5de8d7af7c1f0c9bc2ba6be25`

点击生成密钥(注意：填写后不能修改), 然后就生成了需要的**SecretKey**，copy下来填写到
appContextData.setSecretKey("YourSecretKey");中

## 四、添加天猫精灵设备为真机测试

![真机测试](./img/真机测试.jpg)
点击添加设备，按照提示添加

## FAQ

### 更新下载 AGUIAgentSDK 依赖报错以下错误

```String
ERROR:
ERROR: Manifest merger failed : uses-sdk:minSdkVersion 15 cannot be smaller than version 19 declared in library [com.alibaba.ailabs.aligenie.opensdk:ailabsSDK:3.0.0.8] /Users/zhuwen/.gradle/caches/transforms-2/files-2.1/9c2c5bcefbe3aa4347ef7c44b6fc9abe/ailabsSDK-3.0.0.8/AndroidManifest.xml as the library might be using APIs not available in 15
Suggestion: use a compatible library with a minSdk of at most 15,
or increase this project's minSdk version to at least 19,
or use tools:overrideLibrary="com.alibaba.ailabs.genie.assistant.sdk" to force usage (may lead to runtime failures)
```

minSdkVersion 设置为 19

### 语音提示：现在出来点问题，请稍后再试

检查下图设置是否正确（如果没有请联系阿里开发者帮你设置）
![回复逻辑](./img/回复逻辑.jpg)

## 参考

- [How do I find out which keystore was used to sign an app?
  ](https://stackoverflow.com/questions/11331469/how-do-i-find-out-which-keystore-was-used-to-sign-an-app)
